Connectors
==========

Alongside NumPy, Piquasso also supports TensorFlow and JAX as simulators for calculations.


NumPy connector
---------------

.. automodule:: piquasso._simulators.connectors.numpy_.connector
   :members:


TensorFlow connector
--------------------

.. automodule:: piquasso._simulators.connectors.tensorflow_.connector
   :members:


JAX connector
-------------

.. automodule:: piquasso._simulators.connectors.jax_.connector
   :members: